@@ -8,14 +8,14 @@
 require 'gtk2'
 require 'rsvg2'
 
-require 'mmon/image'
+require 'mmon/component/image'
 
 class Icon
     attr_accessor :name, :exec1, :exec2
 
-    @@color_clicked = Color.new(0.8, 0.5, 0.3, 0.3)
-    @@color_pressed = Color.new(0.8, 0.8, 0.3, 0.3)
-    @@color_entered = Color.new(0.8, 0.8, 0.6, 0.3)
+    @@color_click = Color.new(0.8, 0.5, 0.3, 0.3)
+    @@color_press = Color.new(0.8, 0.8, 0.3, 0.3)
+    @@color_enter = Color.new(0.8, 0.8, 0.6, 0.3)
 
     def initialize(item, w, h, icon_path = '')
         @item = item
@@ -29,11 +29,11 @@ class Icon
         @w = w
         @h = h
 
-        @entered = false
-        @pressed = false
-        @clicked = false
+        @enter = false
+        @press = false
+        @click = false
 
-        @image = nil
+        @image = Image.new(icon_path, @w, @h)
 
         set_icon_path(icon_path)
     end
@@ -64,12 +64,12 @@ class Icon
     end
 
     def press(button)
-        @pressed = true
+        @press = true
     end
 
     def release(button)
-        @pressed = false
-        @clicked = true
+        @press = false
+        @click = true
 
         case button
         when 1 then execute(@exec1)
@@ -78,20 +78,20 @@ class Icon
 
         GLib::Timeout.add(1 * 1000) do  # 1 sec
             #puts 'timeout'
-            @clicked = false
+            @click = false
             @item.redraw_all()
             false
         end
     end
 
     def leave
-        @entered = false
-        @pressed = false
+        @enter = false
+        @press = false
     end
 
-    def move(pressed)
-        @entered = true
-        @pressed = pressed
+    def move(press)
+        @enter = true
+        @press = press
     end
 
     def execute(exec)
@@ -113,13 +113,13 @@ class Icon
         cc.save
         cc.translate(@x, @y)
 
-        if @clicked || @pressed || @entered
-            if @clicked
-                cc.set_source_rgba(@@color_clicked)
-            elsif @pressed
-                cc.set_source_rgba(@@color_pressed)
-            elsif @entered
-                cc.set_source_rgba(@@color_entered)
+        if @click || @press || @enter
+            if @click
+                cc.set_source_rgba(@@color_click)
+            elsif @press
+                cc.set_source_rgba(@@color_press)
+            elsif @enter
+                cc.set_source_rgba(@@color_enter)
             end
             cc.rectangle(-2, -2, @w + 4, @h + 4)
             cc.fill
@@ -182,10 +182,13 @@ class Icon
 #        if File.extname(@icon_path) == '.desktop' 
 #        else
             @image = Image.new(path, @w, @h)
-            @item.redraw_all()
 #        end
     end
 
+    def redraw()
+        @item.redraw_all()
+    end
+
     def icon_path
         @icon_path
     end
@@ -194,7 +197,7 @@ class Icon
 end
 
 class IconSettingWidget < Gtk::VBox
-    def initialize(icon = nil)
+    def initialize
         super()
 
         label_name = Gtk::Label.new('Name:')
@@ -216,12 +219,16 @@ class IconSettingWidget < Gtk::VBox
         @entry_exec1 = Gtk::Entry.new
         @entry_exec2 = Gtk::Entry.new
 
+        @apply_b = Gtk::Button.new('Apply')
+        @apply_b.signal_connect('clicked') { |w| apply() }
+
         @button_icon = Gtk::FileChooserButton.new('Icon', Gtk::FileChooser::Action::OPEN)
         @button_icon.signal_connect('selection-changed') do |w| 
             #puts 'button selection_changed'
 
             if w.filename != nil && @icon != nil
                @icon.set_icon_path(w.filename)
+               @icon.redraw()
             end
         end
 
@@ -245,15 +252,20 @@ class IconSettingWidget < Gtk::VBox
         pack_start(h1, false, false, 10)
         pack_start(h2, false, false, 10)
         pack_start(h3, false, false, 10)
-        signal_connect('destroy') { |w| sync_setting() }
+        pack_start(@apply_b, false, false, 10)
+        #signal_connect('destroy') { |w| apply() }
+        
+        @proc_changed = nil
+    end
 
-        self.icon = icon
+    def proc_changed=(proc)
+        @proc_changed = proc
     end
     
     def icon=(icon)
         return if @icon == icon
 
-        sync_setting()
+        #apply()
 
         @icon = icon
         if @icon.nil?
@@ -275,17 +287,23 @@ class IconSettingWidget < Gtk::VBox
         end
     end
 
-    def sync_setting
+    def apply
         return if @icon.nil?
 
-        puts 'sync_setting'
-        p @button_icon.filename
+        #puts 'apply'
+
+        path = @button_icon.filename
+        if path.nil?
+            path = ''
+        end
 
         @icon.name = @entry_name.text
         @icon.exec1 = @entry_exec1.text
         @icon.exec2 = @entry_exec2.text
-        @icon.set_icon_path(@button_icon.filename)
+        @icon.set_icon_path(path)
+        @icon.redraw()
 
-        puts 'sync_setting end'
+        @proc_changed.call(@icon) unless @proc_changed.nil?
     end
 end
+
