@@ -1,5 +1,3 @@
-#!/usr/bin/ruby -Ku
-#
 # mmon
 #
 # Copyright (c) 2007 sanpo
@@ -12,21 +10,29 @@ require 'rsvg2'
 require 'rexml/document'
 
 require 'mmon/color'
+require 'mmon/root_pixmap'
+require 'mmon/mlogger'
 
 class Item < Gtk::Window
     attr_reader :item_name
 
-    def initialize(parent = nil)
+    def initialize(mmon)
         super(Gtk::Window::TOPLEVEL)
 
-        @parent = parent
+        @mmon = mmon
+
+        @mlog = MLogger.instance
+
         # サイズが必要な時に毎回 window から取ってたが、リサイズしてから window サイズが変更に
         # なるまでの間にサイズを取ると古いサイズが帰るのでメモることにする。
         @width = 72
         @height = 72
+        @x_init = 0
+        @y_init = 0
 
 #        self.resizable = false
 #        self.set_type_hint(Gdk::Window::TypeHint::DOCK)
+
         self.add_events(Gdk::Event::Mask::BUTTON_PRESS_MASK)
         self.app_paintable = true
         self.decorated = false
@@ -39,34 +45,42 @@ class Item < Gtk::Window
         signal_connect("realize")               { |w| realize_handler(w) }
         signal_connect("configure-event")       { |w, e| configure_handler(w, e) }
         signal_connect("button-press-event")    { |w, e| button_press_handler(e) }
+        signal_connect("show")                  { show_handler() }
 
-        screen = self.screen
-        colormap = screen.rgba_colormap
+        colormap = self.screen.rgba_colormap
         if colormap.nil?
-            #puts 'colormap is nil'
-            self.colormap = screen.rgb_colormap
-            Color.use_alpha = false
+            self.colormap = self.screen.rgb_colormap
+            @enable_rgba_colormap = false
         else
-            #puts 'colormap is not nil'
             self.colormap = colormap
-            Color.use_alpha = true
+            @enable_rgba_colormap = true
         end
 
         @interval = 1  # sec
         @timeout_id = 0
 
-        @size_changed = false
+        @configured = false
+
+        @root_pixmap = RootPixmap.instance
 
         @use_bg = false
         @cc_bg = nil
 
         @use_fg = false
         @cc_fg = nil
+    end
 
-        # 子クラスが初期化されてない状態で set_item_size() を呼ぶと不幸がおこる
-        # item 自身は set_item_size() 内でやってる処理が必要ないのでここでは単に resize()
-        #self.set_item_size(@width, @height)
-        self.resize(@width, @height)
+    def enable_rgba_colormap?
+        @enable_rgba_colormap
+    end
+
+    def pseudo_transparency=(bool)
+        if bool
+            @use_bg = true
+            create_bg(@width, @height)
+        else
+            create_bg(@width, @height)
+        end
     end
 
     def item_size
@@ -74,20 +88,30 @@ class Item < Gtk::Window
     end
 
     def set_item_size(w, h)
-#        puts self.class.to_s + " set_item_size w:#{w} h:#{h}"
+        @mlog.debug(self.class.to_s + " set_item_size w:#{w} h:#{h}")
+
         @width = w
         @height = h
         create_bg(w, h) if @use_bg
         create_fg(w, h) if @use_fg
         set_shape_mask(w, h)
-        @size_changed = true
-        self.resize(w, h)
+        @configured = true
+
+        self.window.resize(w, h) unless self.window.nil?
+    end
+
+    def show_handler()
+        @mlog.debug(self.class.to_s + " show x:#{@x_init} y:#{@y_init}")
+
+        if @x_init.zero? && @y_init.zero?
+        else
+            self.move(@x_init, @y_init)
+        end
     end
 
     def destroy_handler(widget, event)
         #puts 'item destroy_handler'
         GLib::Source.remove(@timeout_id) unless @timeout_id.zero?
-        Gtk::main_quit if @parent.nil?
     end
 
     def expose_handler(widget, event)
@@ -96,7 +120,7 @@ class Item < Gtk::Window
         e_w = event.area.width
         e_h = event.area.height
 
-#        puts "expose #{self.class.to_s} #{e_x} #{e_y} #{e_w} #{e_h}"
+        @mlog.debug("expose #{self.class.to_s} #{e_x} #{e_y} #{e_w} #{e_h}")
 
         cc = self.window.create_cairo_context
         cc.rectangle(e_x, e_y, e_w, e_h)
@@ -111,12 +135,12 @@ class Item < Gtk::Window
             cc.paint
         end
 
-        w, h = self.window.size
         cc.operator = Cairo::OPERATOR_OVER
+
+        w, h = self.window.size
         render(cc, w, h)
 
         if @use_fg
-            cc.operator = Cairo::OPERATOR_OVER
             cc.set_source(@cc_fg.target, 0, 0)
             cc.paint
         end
@@ -149,7 +173,7 @@ class Item < Gtk::Window
         menu = Gtk::Menu.new
         menu.append(menuitem_setting)
         menu.append(menuitem_quit)
-        @parent.add_menu(menu) unless @parent.nil?
+        @mmon.add_menu(menu) 
         menu.show_all
         menu.popup(nil, nil, event.button, event.time)
     end
@@ -163,7 +187,7 @@ class Item < Gtk::Window
     end
 
     def show_dialog(x, y)
-        mmon = @parent.setting_widget unless @parent.nil?
+        mmon = @mmon.setting_widget
 
         title = Gtk::Label.new
         title.set_markup('<big><b>' + get_item_name() + '</b></big>')
@@ -176,7 +200,7 @@ class Item < Gtk::Window
         vbox.pack_start(w, true) unless w.nil?
 
         notebook = Gtk::Notebook.new
-        notebook.append_page(mmon, Gtk::Label.new('Mmon')) unless @parent.nil?
+        notebook.append_page(mmon, Gtk::Label.new('Mmon')) 
         notebook.append_page(vbox, Gtk::Label.new(get_item_name())) unless w.nil?
 
         notebook.show_all
@@ -193,7 +217,9 @@ class Item < Gtk::Window
     end
 
     def realize_handler(widget)
-#        puts "realize #{self.class.to_s}"
+        @mlog.debug("realize #{self.class.to_s}")
+
+        self.set_item_size(@width, @height)
 
         unless @interval.zero?
             prepare()
@@ -206,15 +232,26 @@ class Item < Gtk::Window
         y = event.y
         w = event.width
         h = event.height
-#        puts "configure #{self.class.to_s} (x,y)=(#{x} #{y}) :w:#{w} h:#{h}"
+
+        @mlog.debug("configure #{self.class.to_s} (x,y)=(#{x} #{y}) :w:#{w} h:#{h} :: #{@width} #{@height}")
+
+        if w != @width || h != @height
+            # ウィンドウマネージャーのセッション復元時に別ウィンドウのサイズにされて
+            # しまうことがあるのでチェックする。
+            # その場しのぎのごまかし。
+            set_item_size(@width, @height)
+        else
+            create_bg(w, h) if @use_bg   # 疑似透過の背景書き換え用
+        end
+        redraw_all()
     end
 
     def update()
         return if @interval == 0.0
 
-        if prepare() || @size_changed
+        if prepare() || @configured
             #puts 'update interval:' + @interval.to_s
-            @size_changed = false
+            @configured = false
             self.queue_draw()
         end
 
@@ -241,20 +278,6 @@ class Item < Gtk::Window
         cc.paint
         cc.operator = Cairo::OPERATOR_SOURCE
 
-=begin
-        if @use_bg
-            cc.set_source(@cc_bg.target, 0, 0)
-            cc.paint
-        end
-
-        if @use_fg
-            cc.set_source(@cc_fg.target, 0, 0)
-            cc.paint
-        end
-
-        render_bg(cc, w, h) if @use_bg
-        render_fg(cc, w, h) if @use_fg
-=end
         render_mask(cc, w, h)
 
         self.shape_combine_mask(bitmap, 0, 0)
@@ -262,6 +285,17 @@ class Item < Gtk::Window
 
     def create_bg(w, h)
         @cc_bg = create_surface_context(w, h)
+
+        if @root_pixmap
+            root_x, root_y = self.position 
+
+            #puts "root_x:#{root_x} root_y:#{root_y}"
+        
+            @cc_bg.operator = Cairo::OPERATOR_SOURCE
+            @root_pixmap.render(@cc_bg, root_x, root_y)
+            @cc_bg.operator = Cairo::OPERATOR_OVER
+        end
+
         render_bg(@cc_bg, w, h)
     end
 
@@ -281,11 +315,9 @@ class Item < Gtk::Window
     end
 
     def read_element(e)
-        x = e.elements['x'].text.to_i
-        y = e.elements['y'].text.to_i
+        @x_init = e.elements['x'].text.to_i
+        @y_init = e.elements['y'].text.to_i
         
-        self.move(x, y)
-
         read_element_local(e)
     end
 
@@ -322,7 +354,8 @@ class Item < Gtk::Window
 
     def render(cc, w, h)
         cc.set_source_rgba(1.0, 0.0, 0.0, 0.6)
-        cc.paint
+        cc.rectangle(0.0, 0.0, 10.0, 10.0)
+        cc.fill
     end
 
     def render_mask(cc, w, h)
@@ -341,8 +374,11 @@ class Item < Gtk::Window
 end
     
 if __FILE__ == $0
-    item = Item.new
-    item.show
+    require 'mmon/appmmon'
+
+    app = AppMmon.new
+    item = Item.new(app)
+    app.add_item(item)
 
     Gtk::main()
 end
