@@ -5,8 +5,6 @@
 # This program is free software.
 # You can redistribute it and/or modify it under the terms of the GPL.
 
-require 'mmon/item'
-
 class Plugin
     def initialize(class_name = nil)
         @plugin_class = Module.const_get(class_name)
@@ -20,11 +18,11 @@ class Plugin
         end
     end
 
-    def create_object(parent)
+    def create_object(mmon)
         if @plugin_class.nil?
             return nil
         else
-            return @plugin_class.new(parent)
+            return @plugin_class.new(mmon)
         end
     end
 
