@@ -16,21 +16,23 @@ class ItemAClock < Item
 
     @@color_hour = Color.new(0.9, 0.9, 0.0, 0.6)
     @@color_min = Color.new(1.0, 1.0, 0.0, 0.8)
-    @@color_sec = Color.new(0.5, 0.5, 0.5, 0.7)
+    @@color_sec = Color.new(0.8, 0.8, 0.0, 0.7)
 
     @@color_bg = Color.new(0.5, 0.5, 0.5, 0.8)
     @@color_arc = Color.new(0.7, 0.7, 0.7, 1.0)
     @@color_dot = Color.new(0.7, 0.7, 0.0, 1.0)
 
-    def initialize(parent = nil)
-        super(parent)
+    def initialize(mmon)
+        super(mmon)
 
         @item_name = 'Analog Clock'
         @interval = 5.0
         @use_bg = true
-        self.set_item_size(72, 72)
 
         @now = Time.now
+
+        @width = 72
+        @height = 72
     end
 
     private
@@ -40,6 +42,8 @@ class ItemAClock < Item
     end
 
     def render_bg(cc, w, h)
+#        puts "aclock render_bg w:#{w} h:#{h}"
+
         x0 = w / 2.0
         y0 = h / 2.0
         r0 = x0
@@ -69,6 +73,7 @@ class ItemAClock < Item
 
     def render(cc, w, h)
 #        puts "aclock render w:#{w} h:#{h}"
+
         hour = @now.hour
         min = @now.min
         sec = @now.sec
@@ -104,12 +109,12 @@ class ItemAClock < Item
 =begin        
         # sec
         rad = 2.0 * PI * sec / 60.0;
-        x = 0.45 * sin(rad);
-        y = 0.45 * cos(rad);
-        cc.set_line_width(0.01)
+        x = 0.85 * r * sin(rad);
+        y = 0.85 * r * cos(rad);
+        cc.set_line_width(2);
         cc.set_source_rgba(@@color_sec)
-        cc.move_to(0.5, 0.5)
-        cc.line_to(0.5 + x, 0.5 - y)
+        cc.move_to(x0, y0)
+        cc.line_to(x0 + x, y0 - y)
         cc.stroke
 =end
     end
@@ -123,9 +128,11 @@ class ItemAClock < Item
 end
 
 if __FILE__ == $0
-    item = ItemAClock.new
-    p ItemAClock.const_get(:NAME)
-    item.show
+    require 'mmon/appmmon'
+
+    app = AppMmon.new
+    item = ItemAClock.new(app)
+    app.add_item(item)
 
     Gtk::main()
 end
