@@ -9,19 +9,21 @@
 
 require 'mmon/item'
 require 'mmon/util'
-require 'mmon/label'
+require 'mmon/component/label'
 
 class ItemCal < Item
     NAME = 'Calendar'
 
     @@color_text = Color.new(1.0, 1.0, 0.0, 1.0)
 
-    def initialize(parent = nil)
-        super(parent)
+    def initialize(mmon)
+        super(mmon)
 
         @interval = 2.0
         @use_bg = true
-        self.set_item_size(72, 32)
+
+        @width = 72
+        @height = 32
 
         @wtext = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat']
         #@wtext = ['日', '月', '火', '水', '木', '金', '土']
@@ -62,20 +64,23 @@ class ItemCal < Item
         old = @now
         @now = Time.now
 
-        if old.day != @now.day
+        if old.day == @now.day
+            return false
+        else 
             @label_ym.text = @now.strftime('%Y/%m')
             @label_wd.text = @wtext[@now.wday]
             @label_d.text = @now.strftime('%d')
             return true
-        else 
-            return false
         end
     end
 end
 
 if __FILE__ == $0
-    item = ItemCal.new
-    item.show
+    require 'mmon/appmmon'
+
+    app = AppMmon.new
+    item = ItemCal.new(app)
+    app.add_item(item)
 
     Gtk::main()
 end
