@@ -9,19 +9,21 @@
 
 require 'mmon/item'
 require 'mmon/util'
-require 'mmon/label'
+require 'mmon/component/label'
 
 class ItemDClock < Item
     NAME = 'Digital Clock'
 
     @@color_text = Color.new(1.0, 1.0, 0.0, 1.0)
 
-    def initialize(parent = nil)
-        super(parent)
+    def initialize(mmon)
+        super(mmon)
 
         @interval = 2.0
         @use_bg = true
-        self.set_item_size(72, 32)
+
+        @width = 72
+        @height = 32
 
         @now = Time.now
 
@@ -59,8 +61,11 @@ class ItemDClock < Item
 end
 
 if __FILE__ == $0
-    item = ItemDClock.new
-    item.show
+    require 'mmon/appmmon'
+
+    app = AppMmon.new
+    item = ItemDClock.new(app)
+    app.add_item(item)
 
     Gtk::main()
 end
