@@ -9,8 +9,8 @@
 
 require 'mmon/item'
 require 'mmon/util'
-require 'mmon/trend_buffer'
 require 'mmon/network'
+require 'mmon/component/trend_graph'
 
 class ItemNet < Item
     NAME = 'Network'
@@ -18,17 +18,24 @@ class ItemNet < Item
     @@color_in = Color.new(0.0, 1.0, 1.0, 0.8)
     @@color_out = Color.new(0.0, 0.8, 0.8, 0.8)
 
-    def initialize(parent = nil)
-        super(parent)
+    def initialize(mmon)
+        super(mmon)
 
         @interval = 0.5
         @use_bg = true
         @use_fg = true
         w = 72
         h = 32
-        self.set_item_size(w, h)
+        @width = w
+        @height = h
 
-        @trend = TrendBuffer.new(w, h)
+        @trend_in = TrendGraph.new(w - 2 * 2, h / 2  - 3)
+        @trend_in.position(2, 2)
+        @trend_in.color(@@color_in)
+
+        @trend_out = TrendGraph.new(w - 2 * 2, h / 2  - 3)
+        @trend_out.position(2, h / 2 + 1)
+        @trend_out.color(@@color_out)
 
         @in_max = 512000
         @out_max = 64000
@@ -50,46 +57,17 @@ class ItemNet < Item
     end
 
     def render(cc, w, h)
-        tcc = @trend.cairo_context
-
-        cc.set_source(tcc.target, 0, 0)
-        cc.paint
+        @trend_in.render(cc)
+        @trend_out.render(cc)
     end
 
     private
 
     def prepare
-        w, h = self.item_size()
-
         @net.read
 
-        @trend.shift
-        tcc = @trend.cairo_context
-
-        lw = 2.0
-        w2 = lw / 2.0
-
-        rh = h / 2.0 - lw - w2
-
-        x = w - lw
-        y0 = h / 2.0 - w2
-        h0 = -rh * @net.in
-        y1 = h - lw
-        h1 = -rh * @net.out
-
-#puts "y0:#{y0} y1:#{y1} y2:#{y2} y3:#{y3}"
-
-        tcc.set_line_width(1)
-
-        tcc.set_source_rgba(@@color_in)
-        tcc.move_to(x, y0)
-        tcc.rel_line_to(0, h0)
-        tcc.stroke
-
-        tcc.set_source_rgba(@@color_out)
-        tcc.move_to(x, y1)
-        tcc.rel_line_to(0, h1)
-        tcc.stroke
+        @trend_in.value(@net.in)
+        @trend_out.value(@net.out)
 
         return true
     end
@@ -152,8 +130,11 @@ class ItemNet < Item
 end
 
 if __FILE__ == $0
-    item = ItemNet.new
-    item.show
+    require 'mmon/appmmon'
+
+    app = AppMmon.new
+    item = ItemNet.new(app)
+    app.add_item(item)
 
     Gtk::main()
 end
