@@ -9,19 +9,21 @@
 
 require 'mmon/item'
 require 'mmon/util'
-require 'mmon/label'
+require 'mmon/component/label'
 
 class ItemTemp < Item
     NAME = 'Temperature'
 
     @@color_text = Color.new(1.0, 1.0, 0.0, 1.0)
 
-    def initialize(parent = nil)
-        super(parent)
+    def initialize(mmon)
+        super(mmon)
 
         @interval = 1.0
         @use_bg = true
-        self.set_item_size(72, 32)
+
+        @width = 72
+        @height = 32
 
         @temp1_input = ''
         @temp2_input = ''
@@ -147,8 +149,11 @@ class ItemTemp < Item
 end
 
 if __FILE__ == $0
-    item = ItemTemp.new
-    item.show
+    require 'mmon/appmmon'
+
+    app = AppMmon.new
+    item = ItemTemp.new(app)
+    app.add_item(item)
 
     Gtk::main()
 end
