@@ -24,16 +24,18 @@ class ItemVol < Item
 
     NAME = 'Volume'
 
-    @@color_knob = Color.new(1.0, 0.0, 0.0, 0.0)
-    @@color_knob_mute = Color.new(0.5, 0.0, 0.0, 0.0)
+    @@color_knob = Color.new(1.0, 0.0, 0.0, 1.0)
+    @@color_knob_mute = Color.new(0.5, 0.0, 0.0, 1.0)
 
-    def initialize(parent = nil)
-        super(parent)
+    def initialize(mmon)
+        super(mmon)
 
         @interval = 1.0
         @use_bg = true
         @use_fg = true
-        self.set_item_size(72, 20)
+
+        @width = 72
+        @height = 20
 
         self.add_events(Gdk::Event::Mask::BUTTON_PRESS_MASK | Gdk::Event::Mask::SCROLL_MASK)
 		signal_connect("button-press-event")    { |w, e| button_press_event(e) }
@@ -59,7 +61,7 @@ class ItemVol < Item
     end
 
     def render(cc, w, h)
-        #puts 'vol render'
+        #puts "vol render vol:#{@vol}"
 
         l = 2.0
 
@@ -190,8 +192,11 @@ class ItemVol < Item
 end
 
 if __FILE__ == $0
-    item = ItemVol.new
-    item.show
+    require 'mmon/appmmon'
+
+    app = AppMmon.new
+    item = ItemVol.new(app)
+    app.add_item(item)
 
     Gtk::main()
 end
